@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2022 Michael Samoglyadov
+# Copyright 2022-2023 Michael Samoglyadov
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 """Type handlers for nedted diff."""
 
 from difflib import SequenceMatcher
+from math import isnan
 from pickle import dumps
 
 
@@ -150,6 +151,29 @@ class FloatHandler(ScalarHandler):
 
     handled_type = float
 
+    def __init__(self, nans_equal=False):
+        """Initialize handler.
+
+        Args:
+            nans_equal: When True treat NaN (not a number) as equal to NaN.
+
+        """
+        super().__init__()
+
+        if nans_equal:
+            orig_diff_method = self.diff
+
+            def _diff_nan_wrapper(differ, a, b):
+                if isnan(a) and isnan(b):
+                    if differ.op_u:
+                        return True, {'U': a}
+
+                    return True, {}
+
+                return orig_diff_method(differ, a, b)
+
+            self.diff = _diff_nan_wrapper
+
 
 class StrHandler(ScalarHandler):
     """str handler."""
